Author: tkreuzer
Date: Wed Oct 14 13:53:30 2009
New Revision: 43449
URL:
http://svn.reactos.org/svn/reactos?rev=43449&view=rev
Log:
prefix DEBUG_CONTROL constants with AMD64 as they are architecture specific
Modified:
branches/ros-amd64-bringup/reactos/include/reactos/windbgkd.h
branches/ros-amd64-bringup/reactos/ntoskrnl/kd64/amd64/kdsup.c
Modified: branches/ros-amd64-bringup/reactos/include/reactos/windbgkd.h
URL:
http://svn.reactos.org/svn/reactos/branches/ros-amd64-bringup/reactos/inclu…
==============================================================================
--- branches/ros-amd64-bringup/reactos/include/reactos/windbgkd.h [iso-8859-1] (original)
+++ branches/ros-amd64-bringup/reactos/include/reactos/windbgkd.h [iso-8859-1] Wed Oct 14
13:53:30 2009
@@ -195,13 +195,12 @@
#define DBGKD_PARTITION_ALTERNATE 0x01
//
// Control Space types
//
#define DEBUG_CONTROL_SPACE_KPCR 0
#define DEBUG_CONTROL_SPACE_KPRCB 1
#define DEBUG_CONTROL_SPACE_KSPECIAL 2
#define DEBUG_CONTROL_SPACE_KTHREAD 3
#define X86_DEBUG_CONTROL_SPACE_KSPECIAL 716
//
Modified: branches/ros-amd64-bringup/reactos/ntoskrnl/kd64/amd64/kdsup.c
URL:
http://svn.reactos.org/svn/reactos/branches/ros-amd64-bringup/reactos/ntosk…
==============================================================================
--- branches/ros-amd64-bringup/reactos/ntoskrnl/kd64/amd64/kdsup.c [iso-8859-1]
(original)
+++ branches/ros-amd64-bringup/reactos/ntoskrnl/kd64/amd64/kdsup.c [iso-8859-1] Wed Oct 14
13:53:30 2009
@@ -185,25 +185,25 @@
switch ((ULONG_PTR)BaseAddress)
{
- case DEBUG_CONTROL_SPACE_KPCR:
+ case AMD64_DEBUG_CONTROL_SPACE_KPCR:
/* Copy a pointer to the Pcr */
ControlStart = &Pcr;
RealLength = sizeof(PVOID);
break;
- case DEBUG_CONTROL_SPACE_KPRCB:
+ case AMD64_DEBUG_CONTROL_SPACE_KPRCB:
/* Copy a pointer to the Prcb */
ControlStart = &Prcb;
RealLength = sizeof(PVOID);
break;
- case DEBUG_CONTROL_SPACE_KSPECIAL:
+ case AMD64_DEBUG_CONTROL_SPACE_KSPECIAL:
/* Copy SpecialRegisters */
ControlStart = &Prcb->ProcessorState.SpecialRegisters;
RealLength = sizeof(KSPECIAL_REGISTERS);
break;
- case DEBUG_CONTROL_SPACE_KTHREAD:
+ case AMD64_DEBUG_CONTROL_SPACE_KTHREAD:
/* Copy a pointer to the current Thread */
ControlStart = &Prcb->CurrentThread;
RealLength = sizeof(PVOID);
@@ -195,13 +195,12 @@
#define DBGKD_PARTITION_ALTERNATE 0x01
//
-// Control Space types
-//
-#define DEBUG_CONTROL_SPACE_KPCR 0
-#define DEBUG_CONTROL_SPACE_KPRCB 1
-#define DEBUG_CONTROL_SPACE_KSPECIAL 2
-#define DEBUG_CONTROL_SPACE_KTHREAD 3
-#define X86_DEBUG_CONTROL_SPACE_KSPECIAL 716
+// AMD64 Control Space types
+//
+#define AMD64_DEBUG_CONTROL_SPACE_KPCR 0
+#define AMD64_DEBUG_CONTROL_SPACE_KPRCB 1
+#define AMD64_DEBUG_CONTROL_SPACE_KSPECIAL 2
+#define AMD64_DEBUG_CONTROL_SPACE_KTHREAD 3
//
Modified: branches/ros-amd64-bringup/reactos/ntoskrnl/kd64/amd64/kdsup.c